@@ -12,7 +12,7 @@
  * tags describing the message.
  *
  * For further details, see it's initial announcement available at
- *    http://blog.gerhards.net/2010/10/introducing-liblognorm.html
+ *    https://rainer.gerhards.net/2010/10/introducing-liblognorm.html
  *
  * The public interface of this library is describe in liblognorm.h.
  *
@@ -69,7 +69,9 @@
 /* we need to turn off this warning, as it also comes up in C99 mode, which
  * we use.
  */
+#ifndef _AIX
 #pragma GCC diagnostic ignored "-Wdeclaration-after-statement"
+#endif
 
 /* support for simple error checking */
 
