@@ -17,7 +17,7 @@
  * tags describing the message.
  *
  * For further details, see it's initial announcement available at
- *    http://blog.gerhards.net/2010/10/introducing-liblognorm.html
+ *    https://rainer.gerhards.net/2010/10/introducing-liblognorm.html
  *
  * The public interface of this library is describe in liblognorm.h.
  *
@@ -36,7 +36,7 @@
  *//*
  *
  * liblognorm - a fast samples-based log normalization library
- * Copyright 2010-2013 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2010-2017 by Rainer Gerhards and Adiscon GmbH.
  *
  * Modified by Pavel Levshin (pavel@levshin.spb.ru) in 2013
  *
@@ -61,7 +61,6 @@
 #ifndef LIBLOGNORM_H_INCLUDED
 #define LIBLOGNORM_H_INCLUDED
 #include <stdlib.h>	/* we need size_t */
-#include <libestr.h>
 #include <json.h>
 
 /* error codes */
@@ -72,6 +71,7 @@
 #define LN_WRONGPARSER -1000
 
 #define LN_RB_LINE_TOO_LONG -1001
+#define LN_OVER_SIZE_LIMIT -1002
 
 /**
  * The library context descriptor.
@@ -92,7 +92,15 @@ typedef struct ln_ctx_s* ln_ctx;
 /* Note: this MUST NOT be inline to make sure the actual library
  * has the right version, not just what was used to compile!
  */
-char *ln_version(void);
+const char *ln_version(void);
+
+/**
+ * Return if library is build with advanced statistics
+ * activated.
+ *
+ * @return 1 if advanced stats are active, 0 if not
+ */
+int ln_hasAdvancedStats(void);
 
 /**
  * Initialize a library context.
@@ -100,7 +108,7 @@ char *ln_version(void);
  * To prevent memory leaks, ln_exitCtx() must be called on a library
  * context that is no longer needed.
  *
- * @return new library context or NULL if an error occured
+ * @return new library context or NULL if an error occurred
  */
 ln_ctx ln_initCtx(void);
 
@@ -108,19 +116,19 @@ ln_ctx ln_initCtx(void);
  * Inherit control attributes from a library context.
  *
  * This does not copy the parse-tree, but does copy
- * behaviour-controling attributes such as enableRegex.
+ * behaviour-controlling attributes such as enableRegex.
  *
  * Just as with ln_initCtx, ln_exitCtx() must be called on a library
  * context that is no longer needed.
  *
- * @return new library context or NULL if an error occured
+ * @return new library context or NULL if an error occurred
  */
 ln_ctx ln_inherittedCtx(ln_ctx parent);
 
 /**
  * Discard a library context.
  *
- * Free's the ressources associated with the given library context. It
+ * Free's the resources associated with the given library context. It
  * MUST NOT be accessed after calling this function.
  *
  * @param ctx The context to be discarded.
@@ -130,14 +138,21 @@ ln_ctx ln_inherittedCtx(ln_ctx parent);
 int ln_exitCtx(ln_ctx ctx);
 
 
+/* binary values, so that we can "or" them together */
+#define LN_CTXOPT_ALLOW_REGEX		0x01 /**< permit regex matching */
+#define LN_CTXOPT_ADD_EXEC_PATH		0x02 /**< add exec_path attribute (time-consuming!) */
+#define LN_CTXOPT_ADD_ORIGINALMSG	0x04 /**< always add original message to output
+					          (not just in error case) */
+#define LN_CTXOPT_ADD_RULE		0x08 /**< add mockup rule */
+#define LN_CTXOPT_ADD_RULE_LOCATION	0x10 /**< add rule location (file, lineno) to metadata */
 /**
  * Set options on ctx.
  *
  * @param ctx The context to be modified.
- * @param allow_regex A boolean indicating regex-usage should/shouldn't be allowed
+ * @param opts a potentially or-ed list of options, see LN_CTXOPT_*
  */
 void
-ln_setCtxOpts(ln_ctx ctx, int allow_regex);
+ln_setCtxOpts(ln_ctx ctx, unsigned opts);
 
 
 /**
@@ -147,7 +162,7 @@ ln_setCtxOpts(ln_ctx ctx, int allow_regex);
  * - it's internal processing
  * - the way a log message is being normalized
  *
- * It does so by emiting "interesting" information about its processing
+ * It does so by emitting "interesting" information about its processing
  * at various stages. A caller can obtain this information by registering
  * an entry point. When done so, liblognorm will call the entry point
  * whenever it has something to emit. Note that debugging can be rather
@@ -168,7 +183,7 @@ ln_setCtxOpts(ln_ctx ctx, int allow_regex);
  * @param[in] cookie Opaque cookie to be passed down to debug handler. Can be
  *                   used for some state tracking by the caller. This is defined as
  *                   void* to support pointers. To play it safe, a pointer should be
- *                   passed (but advantorous folks may also use an unsigned).
+ *                   passed (but adventurous folks may also use an unsigned).
  *
  * @return Returns zero on success, something else otherwise.
  */
@@ -193,20 +208,6 @@ int ln_setErrMsgCB(ln_ctx ctx, void (*cb)(void*, const char*, size_t), void *coo
  */
 void ln_enableDebug(ln_ctx ctx, int i);
 
-/**
- * Reads a sample stored in buffer buf and creates a new ln_samp object
- * out of it.
- *
- * @note
- * It is the caller's responsibility to delete the newly
- * created ln_samp object if it is no longer needed.
- *
- * @param[ctx] ctx current library context
- * @param[buf] NULL terminated cstr containing the contents of the sample
- * @return Returns zero on success, something else otherwise.
- */
-int
-ln_loadSample(ln_ctx ctx, const char *buf);
 
 /**
  * Load a (log) sample file.
@@ -223,6 +224,18 @@ ln_loadSample(ln_ctx ctx, const char *buf);
  */
 int ln_loadSamples(ln_ctx ctx, const char *file);
 
+/**
+ * Load a rulebase via a string.
+ *
+ * Note: this can only load v2 samples, v1 is NOT supported.
+ *
+ * @param[in] ctx The library context to apply callback to.
+ * @param[in] string The string with the actual rulebase.
+ *
+ * @return Returns zero on success, something else otherwise.
+ */
+int ln_loadSamplesFromString(ln_ctx ctx, const char *string);
+
 /**
  * Normalize a message.
  *
@@ -244,20 +257,11 @@ int ln_loadSamples(ln_ctx ctx, const char *file);
  * @param[in] ctx The library context to use.
  * @param[in] str The message string (see note above).
  * @param[in] strLen The length of the message in bytes.
- * @param[out] json_p A new event record or NULL if an error occured. <b>Must be
+ * @param[out] json_p A new event record or NULL if an error occurred. <b>Must be
  *                   destructed if no longer needed.</b>
  *
  * @return Returns zero on success, something else otherwise.
  */
-int ln_normalize(ln_ctx ctx, const char *str, size_t strLen, struct json_object **json_p);
-
-/* here we add some stuff from the compatibility layer. A separate include
- * would be cleaner, but would potentially require changes all over the
- * place. So doing it here is better. The respective replacement
- * functions should usually be found under ./compat -- rgerhards, 2015-05-20
- */
-#ifndef HAVE_STRNDUP
-char * strndup(const char *s, size_t n);
-#endif
+int ln_normalize(ln_ctx ctx, const char *str, const size_t strLen, struct json_object **json_p);
 
 #endif /* #ifndef LOGNORM_H_INCLUDED */
