@@ -3,21 +3,7 @@
  *
  * This file is part of liblognorm.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- * A copy of the LGPL v2.1 can be found in the file "COPYING" in this distribution.
+ * Released under ASL 2.0
  */
 #include "config.h"
 #include <stdlib.h>
@@ -25,10 +11,8 @@
 #include <stdarg.h>
 #include <string.h>
 
-#include "json_compatibility.h"
 #include "liblognorm.h"
 #include "lognorm.h"
-#include "ptree.h"
 
 /* Code taken from rsyslog ASL 2.0 code.
  * From varmojfekoj's mail on why he provided rs_strerror_r():
@@ -70,7 +54,7 @@ rs_strerror_r(const int errnum, char *const buf, const size_t buflen) {
  * immediately.
  */
 void
-ln_dbgprintf(ln_ctx ctx, char *fmt, ...)
+ln_dbgprintf(ln_ctx ctx, const char *fmt, ...)
 {
 	va_list ap;
 	char buf[8*1024];
@@ -83,7 +67,7 @@ ln_dbgprintf(ln_ctx ctx, char *fmt, ...)
 	lenBuf = vsnprintf(buf, sizeof(buf), fmt, ap);
 	va_end(ap);
 	if(lenBuf >= sizeof(buf)) {
-		/* prevent buffer overrruns and garbagge display */
+		/* prevent buffer overruns and garbage display */
 		buf[sizeof(buf) - 5] = '.';
 		buf[sizeof(buf) - 4] = '.';
 		buf[sizeof(buf) - 3] = '.';
@@ -121,7 +105,7 @@ ln_errprintf(const ln_ctx ctx, const int eno, const char *fmt, ...)
 	lenBuf = vsnprintf(buf, sizeof(buf), fmt, ap);
 	va_end(ap);
 	if(lenBuf >= sizeof(buf)) {
-		/* prevent buffer overrruns and garbagge display */
+		/* prevent buffer overruns and garbage display */
 		buf[sizeof(buf) - 5] = '.';
 		buf[sizeof(buf) - 4] = '.';
 		buf[sizeof(buf) - 3] = '.';
@@ -131,15 +115,24 @@ ln_errprintf(const ln_ctx ctx, const int eno, const char *fmt, ...)
 	}
 
 	if(eno != 0) {
-		rs_strerror_r(eno, errbuf, sizeof(errbuf));
+		rs_strerror_r(eno, errbuf, sizeof(errbuf)-1);
 		lenBuf = snprintf(finalbuf, sizeof(finalbuf), "%s: %s", buf, errbuf);
 		msg = finalbuf;
 	} else {
 		msg = buf;
 	}
 
-	ctx->errmsgCB(ctx->dbgCookie, buf, lenBuf);
-	ln_dbgprintf(ctx, "%s", finalbuf);
+	if(ctx->conf_file != NULL) {
+		/* error during config processing, add line info */
+		const char *const m = strdup(msg);
+		lenBuf = snprintf(finalbuf, sizeof(finalbuf), "rulebase file %s[%d]: %s",
+			ctx->conf_file, ctx->conf_ln_nbr, m);
+		msg = finalbuf;
+		free((void*) m);
+	}
+
+	ctx->errmsgCB(ctx->dbgCookie, msg, lenBuf);
+	ln_dbgprintf(ctx, "%s", msg);
 done:	return;
 }
 
