@@ -988,7 +988,7 @@ struct data_HexNumber {
 /**
  * Parse a hex Number.
  * A hex number begins with 0x and contains only hex digits until the terminating
- * whitespace. Note that if a non-hex character is deteced inside the number string,
+ * whitespace. Note that if a non-hex character is detected inside the number string,
  * this is NOT considered to be a number.
  */
 PARSER_Parse(HexNumber)
@@ -1148,8 +1148,8 @@ done:
  * Parse whitespace.
  * This parses all whitespace until the first non-whitespace character
  * is found. This is primarily a tool to skip to the next "word" if
- * the exact number of whitspace characters (and type of whitespace)
- * is not known. The current parsing position MUST be on a whitspace,
+ * the exact number of whitespace characters (and type of whitespace)
+ * is not known. The current parsing position MUST be on a whitespace,
  * else the parser does not match.
  * This parser is also a forward-compatibility tool for the upcoming
  * slsa (simple log structure analyser) tool.
@@ -2405,25 +2405,92 @@ isValidNameChar(const char c)
 static int
 parseNameValue(npb_t *const npb,
 	size_t *const __restrict__ offs,
-	struct json_object *const __restrict__ valroot)
+	struct json_object *const __restrict__ valroot,
+        const char sep, const char ass)
 {
 	int r = LN_WRONGPARSER;
 	size_t i = *offs;
 	char *name = NULL;
 
 	const size_t iName = i;
-	while(i < npb->strLen && isValidNameChar(npb->str[i]))
+	/*
+	If the assignator character is specified, search for it
+	If it's not, check key name validity
+	*/
+	while(i < npb->strLen && ((ass != 0) ? (npb->str[i] != ass) : isValidNameChar(npb->str[i])))
 		++i;
-	if(i == iName || npb->str[i] != '=')
+	if(i == iName || ((ass != 0) ? (npb->str[i] != ass) : (npb->str[i] != '=')))
 		goto done; /* no name at all! */
 
 	const size_t lenName = i - iName;
-	++i; /* skip '=' */
+	++i; /* skip assignator */
+
+	char quoting = npb->str[i];
+	if(i < npb->strLen && (quoting == '"' || quoting == '\''))
+		i++;
+	else
+		quoting = 0;	//no quoting detected
 
 	const size_t iVal = i;
-	while(i < npb->strLen && !isspace(npb->str[i]))
+	if(quoting) {
+		// wait on an unescaped matching quoting
+
+		/*
+		 * Fix by HSoszynski & KGuillemot to handle escaped quote & backslash infinitly
+		 * Continue while we don't encounter the ending quote, and while it's not escaped
+		 * a" => end
+		 * a\" => continue
+		 * a\\" => end
+		 * a\\\" => continue
+		 * ...
+		 */
+		int continuous_backslash = 0;
+		while(i < npb->strLen && (npb->str[i] != quoting || continuous_backslash%2 == 1 )) {
+			if ( npb->str[i] == '\\' ) {
+				continuous_backslash++;
+			} else {
+				continuous_backslash = 0;
+			}
+			++i;
+		}
+	}
+	else {
+		/* We seek characters as long as:
+		- we have characters remaining
+		- the character is NOT a whitespace (default separator)
+		- the character is NOT the separator set explicitely by the user (sep)
+		- the character IS the separator (sep), BUT is escaped
+		*/
+		/*
+		 * Fix by HSoszynski & KGuillemot to handle escaped separator & backslash infinitly
+		 * Continue while we don't encounter the ending separator, and while it's not escaped
+		 * a, => end
+		 * a\, => continue
+		 * a\\, => end
+		 * a\\\, => continue
+		 * ...
+		 */
+		int continuous_backslash = 0;
+		while(i < npb->strLen
+			&& ((sep == 0 ? (!isspace(npb->str[i])) : (npb->str[i] != sep))
+				|| continuous_backslash%2 == 1)) {
+			if ( npb->str[i] == '\\' ) {
+				continuous_backslash++;
+			} else {
+				continuous_backslash = 0;
+			}
+			++i;
+		}
+	}
+
+	// in case of quoting, ensure we skip it
+	if(i < npb->strLen && npb->str[i] == quoting)
 		++i;
-	const size_t lenVal = i - iVal;
+	else if(quoting)
+		goto done;
+
+
+	const size_t lenVal = i - iVal - (quoting ? 1 : 0);
 
 	/* parsing OK */
 	*offs = i;
@@ -2501,6 +2568,12 @@ done:
 	return r;
 }
 
+
+struct data_NameValue {
+	char sep;       /* separator (between key/value couples) */
+	char ass;	/* assignator (between key and value) */
+};
+
 /**
  * Parser for name/value pairs.
  * On entry must point to alnum char. All following chars must be
@@ -2515,12 +2588,24 @@ done:
  */
 PARSER_Parse(NameValue)
 	size_t i = *offs;
+        struct data_NameValue *const data = (struct data_NameValue*) pdata;
+        const char sep = data->sep;
+        const char ass = data->ass;
+
+        LN_DBGPRINTF(npb->ctx, "in parse_NameValue, separator is '%c'(0x%02x) assignator is '%c'(0x%02x)"
+			,sep, sep, ass, ass);
 
 	/* stage one */
 	while(i < npb->strLen) {
-		CHKR(parseNameValue(npb, &i, NULL));
-		while(i < npb->strLen && isspace(npb->str[i]))
-			++i;
+		if (parseNameValue(npb, &i, NULL, sep, ass) == 0 ) {
+			// Check if there is at least one time the separator after value
+			if( i < npb->strLen && !(sep == 0 ? (isspace(npb->str[i])) : (npb->str[i] == sep)) )
+				break;
+			while(i < npb->strLen && (sep == 0 ? (isspace(npb->str[i])) : (npb->str[i] == sep)))
+				++i;
+		} else {
+			break;
+		}
 	}
 
 	/* success, persist */
@@ -2534,9 +2619,15 @@ PARSER_Parse(NameValue)
 	i = *offs;
 	CHKN(*value = json_object_new_object());
 	while(i < npb->strLen) {
-		CHKR(parseNameValue(npb, &i, *value));
-		while(i < npb->strLen && isspace(npb->str[i]))
-			++i;
+		if (parseNameValue(npb, &i, *value, sep, ass) == 0 ) {
+			// Check if there is at least one time the separator after value
+			if( i < npb->strLen && !(sep == 0 ? (isspace(npb->str[i])) : (npb->str[i] == sep)) )
+				break;
+			while(i < npb->strLen && ((sep == 0) ? (isspace(npb->str[i])) : (npb->str[i] == sep)))
+				++i;
+		} else {
+			break;
+		}
 	}
 
 	/* TODO: fix mem leak if alloc json fails */
@@ -2545,6 +2636,64 @@ done:
 	return r;
 }
 
+PARSER_Construct(NameValue)
+{
+        int r = 0;
+        LN_DBGPRINTF(ctx, "in parser_construct NameValue");
+        struct data_NameValue *data = (struct data_NameValue*) calloc(1, sizeof(struct data_NameValue));
+        struct json_object *obj;
+        const char *str;
+
+        if(json_object_object_get_ex(json, "extradata", &obj) != 0) {
+		LN_DBGPRINTF(ctx, "found 'extradata' in fields, assigning to 'separator'");
+                if(json_object_get_string_len(obj) == 1) {
+                        str = json_object_get_string(obj);
+                        data->sep = str[0];
+                }
+		else {
+			ln_errprintf(ctx, 0, "name-value-list's extradata should only be 1 character");
+			r = LN_BADCONFIG;
+			goto done;
+		}
+        }
+
+        if(json_object_object_get_ex(json, "separator", &obj) != 0) {
+		LN_DBGPRINTF(ctx, "found 'separator' in fields");
+                if(json_object_get_string_len(obj) == 1) {
+                        str = json_object_get_string(obj);
+                        data->sep = str[0];
+                }
+		else {
+			ln_errprintf(ctx, 0, "name-value-list's 'separator' field should only be 1 character");
+			r = LN_BADCONFIG;
+			goto done;
+		}
+        }
+
+        if(json_object_object_get_ex(json, "assignator", &obj) != 0) {
+		LN_DBGPRINTF(ctx, "found 'assignator' in fields");
+                if(json_object_get_string_len(obj) == 1) {
+                        str = json_object_get_string(obj);
+                        data->ass = str[0];
+                }
+		else {
+			ln_errprintf(ctx, 0, "name-value-list's 'assignator' field should only be 1 character");
+			r = LN_BADCONFIG;
+			goto done;
+		}
+        }
+
+	*pdata = data;
+done:
+	if(r != 0)
+		free(data);
+        return r;
+}
+PARSER_Destruct(NameValue)
+{
+        free(pdata);
+}
+
 /**
  * Parse a MAC layer address.
  * The standard (IEEE 802) format for printing MAC-48 addresses in
@@ -2626,7 +2775,8 @@ cefParseExtensionValue(npb_t *const npb,
 			if(npb->str[i] != '=' &&
 			   npb->str[i] != '\\' &&
 			   npb->str[i] != 'r' &&
-			   npb->str[i] != 'n')
+			   npb->str[i] != 'n' && 
+			   npb->str[i] != '/')
 			FAIL(LN_WRONGPARSER);
 			inEscape = 0;
 		} else {
@@ -2661,7 +2811,7 @@ done:
  * of end of name.
  * Note: ArcSight violates the CEF spec ifself: they generate
  * leading underscores in their extension names, which are
- * definetly not alphanumeric. We still accept them...
+ * definitely not alphanumeric. We still accept them...
  * They also seem to use dots.
  */
 static int
@@ -2703,16 +2853,22 @@ cefParseExtensions(npb_t *const npb,
 			++i;
 		iName = i;
 		CHKR(cefParseName(npb, &i));
-		if(i+1 >= npb->strLen || npb->str[i] != '=')
+
+		if(npb->str[i] != '=')
 			FAIL(LN_WRONGPARSER);
 		lenName = i - iName;
-		++i; /* skip '=' */
+		
+		/* Init if the last value is empty */
+		lenValue = 0;
+		if(i < npb->strLen){
+			++i; /* skip '=' */
 
-		iValue = i;
-		CHKR(cefParseExtensionValue(npb, &i));
-		lenValue = i - iValue;
+			iValue = i;
+			CHKR(cefParseExtensionValue(npb, &i));
+			lenValue = i - iValue;
 
-		++i; /* skip past value */
+			++i; /* skip past value */
+		}
 
 		if(jroot != NULL) {
 			CHKN(name = malloc(sizeof(char) * (lenName + 1)));
@@ -2733,6 +2889,8 @@ cefParseExtensions(npb_t *const npb,
 							break;
 					case '\\':	value[iDst] = '\\';
 							break;
+					case '/':	value[iDst] = '/';
+							break;
 					default:	break;
 					}
 				} else {
@@ -2822,7 +2980,7 @@ PARSER_Parse(CEF)
 	char *name = NULL;
 	char *severity = NULL;
 
-	/* minumum header: "CEF:0|x|x|x|x|x|x|" -->  17 chars */
+	/* minimum header: "CEF:0|x|x|x|x|x|x|" -->  17 chars */
 	if(npb->strLen < i + 17 ||
 	   npb->str[i]   != 'C' ||
 	   npb->str[i+1] != 'E' ||
@@ -2840,14 +2998,16 @@ PARSER_Parse(CEF)
 	CHKR(cefGetHdrField(npb, &i, (value == NULL) ? NULL : &sigID));
 	CHKR(cefGetHdrField(npb, &i, (value == NULL) ? NULL : &name));
 	CHKR(cefGetHdrField(npb, &i, (value == NULL) ? NULL : &severity));
-	++i; /* skip over terminal '|' */
+
+	while(i < npb->strLen && npb->str[i] == ' ') /* skip leading SP */
+		++i;
 
 	/* OK, we now know we have a good header. Now, we need
 	 * to process extensions.
 	 * This time, we do NOT pre-process the extension, but rather
 	 * persist them directly to JSON. This is contrary to other
 	 * parsers, but as the CEF header is pretty unique, this time
-	 * it is exteremely unlike we will get a no-match during
+	 * it is extremely unlikely we will get a no-match during
 	 * extension processing. Even if so, nothing bad happens, as
 	 * the extracted data is discarded. But the regular case saves
 	 * us processing time and complexity. The only time when we
