@@ -1,6 +1,6 @@
 /*
  * liblognorm - a fast samples-based log normalization library
- * Copyright 2010-2015 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2010-2018 by Rainer Gerhards and Adiscon GmbH.
  *
  * Modified by Pavel Levshin (pavel@levshin.spb.ru) in 2013
  *
@@ -582,7 +582,7 @@ done:
 /**
  * Parse a hex Number.
  * A hex number begins with 0x and contains only hex digits until the terminating
- * whitespace. Note that if a non-hex character is deteced inside the number string,
+ * whitespace. Note that if a non-hex character is detected inside the number string,
  * this is NOT considered to be a number.
  */
 PARSER(HexNumber)
@@ -670,8 +670,8 @@ done:
  * Parse whitespace.
  * This parses all whitespace until the first non-whitespace character
  * is found. This is primarily a tool to skip to the next "word" if
- * the exact number of whitspace characters (and type of whitespace)
- * is not known. The current parsing position MUST be on a whitspace,
+ * the exact number of whitespace characters (and type of whitespace)
+ * is not known. The current parsing position MUST be on a whitespace,
  * else the parser does not match.
  * This parser is also a forward-compatibility tool for the upcoming
  * slsa (simple log structure analyser) tool.
@@ -734,7 +734,7 @@ done:
  */
 PARSER(StringTo)
 	const char *c;
-	const char *toFind;
+	char *toFind = NULL;
 	size_t i, j, k, m;
 	int chkstr;
 	assert(str != NULL);
@@ -772,6 +772,7 @@ PARSER(StringTo)
 
 	r = 0; /* success */
 done:
+	if(toFind != NULL) free(toFind);
 	return r;
 }
 
@@ -907,7 +908,8 @@ PARSER(Recursive)
 			json_object_put(*value);
 			*value = NULL;
 			*parsed = 0;
-		} else if (pData->remaining_field != NULL && json_object_object_get_ex(*value, pData->remaining_field, &unparsed)) {
+		} else if (pData->remaining_field != NULL
+			&& json_object_object_get_ex(*value, pData->remaining_field, &unparsed)) {
 			*parsed = strLen - *offs - json_object_get_string_len(unparsed);
 			json_object_object_del(*value, pData->remaining_field);
 		} else {
@@ -942,13 +944,18 @@ _recursive_parser_data_constructor(ln_fieldList_t *node,
 	r = 0;
 done:
 	if (r != 0) {
-		if (name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for recursive/descent field name");
-		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
-		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
-		else if (pData->ctx == NULL) ln_dbgprintf(ctx, "recursive/descent normalizer context creation "
+		if (name == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for recursive/descent field name");
+		else if (pData == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
+		else if (args == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
+		else if (pData->ctx == NULL)
+			ln_dbgprintf(ctx, "recursive/descent normalizer context creation "
 		"doneed for field: %s", name);
-		else if (pData->remaining_field == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for remaining-field name for "
-															  "recursive/descent field: %s", name);
+		else if (pData->remaining_field == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for remaining-field name for "
+				"recursive/descent field: %s", name);
 
 		recursive_parser_data_destructor((void**) &pData);
 	}
@@ -958,8 +965,8 @@ done:
 }
 
 static ln_ctx identity_recursive_parse_ctx_constructor(ln_ctx parent_ctx,
-													   __attribute__((unused)) pcons_args_t* args,
-													   __attribute__((unused)) const char* field_name) {
+	__attribute__((unused)) pcons_args_t* args,
+	__attribute__((unused)) const char* field_name) {
 	return parent_ctx;
 }
 
@@ -977,10 +984,15 @@ static ln_ctx child_recursive_parse_ctx_constructor(ln_ctx parent_ctx, pcons_arg
 	CHKR(ln_v1_loadSamples(ctx, rb));
 done:
 	if (r != 0) {
-		if (rb == NULL) ln_dbgprintf(parent_ctx, "file-name for descent rulebase not provided for field: %s", field_name);
-		else if (ctx == NULL) ln_dbgprintf(parent_ctx, "couldn't allocate memory to create descent-field "
-		"normalizer context for field: %s", field_name);
-		else ln_dbgprintf(parent_ctx, "couldn't load samples into descent context for field: %s", field_name);
+		if (rb == NULL)
+			ln_dbgprintf(parent_ctx, "file-name for descent rulebase not provided for field: %s",
+				field_name);
+		else if (ctx == NULL)
+			ln_dbgprintf(parent_ctx, "couldn't allocate memory to create descent-field normalizer "
+				"context for field: %s", field_name);
+		else
+			ln_dbgprintf(parent_ctx, "couldn't load samples into descent context for field: %s",
+				field_name);
 		if (ctx != NULL) ln_exitCtx(ctx);
 		ctx = NULL;
 	}
@@ -1052,9 +1064,11 @@ PARSER(Tokenized)
 
 			if (remaining) json_object_put(remaining);
 
-			if (pData->use_default_field && json_object_object_get_ex(json_p, DEFAULT_MATCHED_FIELD_NAME, &match)) {
+			if (pData->use_default_field
+				&& json_object_object_get_ex(json_p, DEFAULT_MATCHED_FIELD_NAME, &match)) {
 				json_object_array_add(matches, json_object_get(match));
-			} else if (! (pData->use_default_field || json_object_object_get_ex(json_p, UNPARSED_DATA_KEY, &match))) {
+			} else if (! (pData->use_default_field
+				|| json_object_object_get_ex(json_p, UNPARSED_DATA_KEY, &match))) {
 				json_object_array_add(matches, json_object_get(json_p));
 			} else {
 				if (json_object_array_length(matches) > 0) {
@@ -1072,7 +1086,8 @@ PARSER(Tokenized)
 				if (remaining_len > 0) {
 					remaining_str = json_object_get_string(json_object_get(remaining));
 					json_object_object_del(json_p, pData->remaining_field);
-					if (es_strbufcmp(pData->tok_str, (const unsigned char *)remaining_str, es_strlen(pData->tok_str))) {
+					if (es_strbufcmp(pData->tok_str, (const unsigned char *)remaining_str,
+					es_strlen(pData->tok_str))) {
 						json_object_put(remaining);
 						break;
 					} else {
@@ -1214,17 +1229,26 @@ void* tokenized_parser_data_constructor(ln_fieldList_t *node, ln_ctx ctx) {
 	r = 0;
 done:
 	if (r != 0) {
-		if (name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for tokenized-field name");
-		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
-		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
-		else if (tok == NULL) ln_dbgprintf(ctx, "token-separator not provided for field: %s", name);
-		else if (pData->tok_str == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for token-separator "
-		"for field: %s", name);
-		else if (field_descr == NULL) ln_dbgprintf(ctx, "field-type not provided for field: %s", name);
-		else if (field == NULL) ln_dbgprintf(ctx, "couldn't resolve single-token field-type for tokenized field: %s", name);
-		else if (pData->ctx == NULL) ln_dbgprintf(ctx, "couldn't initialize normalizer-context for field: %s", name);
-		else if (pData->remaining_field == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for "
-															  "remaining-field-name for field: %s", name);
+		if (name == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for tokenized-field name");
+		else if (args == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
+		else if (pData == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
+		else if (tok == NULL)
+			ln_dbgprintf(ctx, "token-separator not provided for field: %s", name);
+		else if (pData->tok_str == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for token-separator "
+			"for field: %s", name);
+		else if (field_descr == NULL)
+			ln_dbgprintf(ctx, "field-type not provided for field: %s", name);
+		else if (field == NULL)
+			ln_dbgprintf(ctx, "couldn't resolve single-token field-type for tokenized field: %s", name);
+		else if (pData->ctx == NULL)
+			ln_dbgprintf(ctx, "couldn't initialize normalizer-context for field: %s", name);
+		else if (pData->remaining_field == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for "
+				"remaining-field-name for field: %s", name);
 		if (pData) tokenized_parser_data_destructor((void**) &pData);
 	}
 	if (name != NULL) free(name);
@@ -1268,7 +1292,8 @@ PARSER(Regex)
 				if (pData->consume_group != pData->return_group) {
 					char* val = NULL;
 					if((val = strndup(str + ovector[2 * pData->return_group],
-						ovector[2 * pData->return_group + 1] - ovector[2 * pData->return_group])) == NULL) {
+						ovector[2 * pData->return_group + 1] -
+						ovector[2 * pData->return_group])) == NULL) {
 						free(ovector);
 						FAIL(LN_NOMEM);
 					}
@@ -1337,25 +1362,34 @@ void* regex_parser_data_constructor(ln_fieldList_t *node, ln_ctx ctx) {
 	pcons_unescape_arg(args, 0);
 	CHKN(exp = pcons_arg_copy(args, 0, NULL));
 
-	if ((grp_parse_err = regex_parser_configure_consume_and_return_group(args, pData)) != NULL) FAIL(LN_BADCONFIG);
+	if ((grp_parse_err = regex_parser_configure_consume_and_return_group(args, pData)) != NULL)
+		FAIL(LN_BADCONFIG);
 
 	CHKN(pData->re = pcre_compile(exp, 0, &error, &erroffset, NULL));
 
-	pData->max_groups = ((pData->consume_group > pData->return_group) ? pData->consume_group : pData->return_group) + 1;
+	pData->max_groups = ((pData->consume_group > pData->return_group) ? pData->consume_group :
+					pData->return_group) + 1;
 	r = 0;
 done:
 	if (r != 0) {
-		if (name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory regex-field name");
-		else if (! ctx->opts & LN_CTXOPT_ALLOW_REGEX) ln_dbgprintf(ctx, "regex support is not enabled for: '%s' "
-												 "(please check lognorm context initialization)", name);
-		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
-		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
-		else if (unescaped_exp == NULL) ln_dbgprintf(ctx, "regular-expression missing for field: '%s'", name);
-		else if (exp == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for regex-string for field: '%s'", name);
-		else if (grp_parse_err != NULL)  ln_dbgprintf(ctx, "%s for: '%s'", grp_parse_err, name);
+		if (name == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory regex-field name");
+		else if (! ctx->opts & LN_CTXOPT_ALLOW_REGEX)
+			ln_dbgprintf(ctx, "regex support is not enabled for: '%s' "
+				"(please check lognorm context initialization)", name);
+		else if (pData == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
+		else if (args == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
+		else if (unescaped_exp == NULL)
+			ln_dbgprintf(ctx, "regular-expression missing for field: '%s'", name);
+		else if (exp == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for regex-string for field: '%s'", name);
+		else if (grp_parse_err != NULL)
+			ln_dbgprintf(ctx, "%s for: '%s'", grp_parse_err, name);
 		else if (pData->re == NULL)
 			ln_dbgprintf(ctx, "couldn't compile regex(encountered error '%s' at char '%d' in pattern) "
-												 "for regex-matched field: '%s'", error, erroffset, name);
+				 "for regex-matched field: '%s'", error, erroffset, name);
 		regex_parser_data_destructor((void**)&pData);
 	}
 	if (exp != NULL) free(exp);
@@ -1501,16 +1535,23 @@ void* interpret_parser_data_constructor(ln_fieldList_t *node, ln_ctx ctx) {
 	r = 0;
 done:
 	if (r != 0) {
-		if (name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for interpret-field name");
-		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
-		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
-		else if (type_str == NULL) ln_dbgprintf(ctx, "no type provided for interpretation of field: %s", name);
-		else if (bad_interpret != 0) ln_dbgprintf(ctx, "interpretation to unknown type '%s' requested for field: %s",
-												  type_str, name);
-		else if (field_type == NULL) ln_dbgprintf(ctx, "field-type to actually match the content not provided for "
-												  "field: %s", name);
-		else if (pData->ctx == NULL) ln_dbgprintf(ctx, "couldn't instantiate the normalizer context for matching "
-												  "field: %s", name);
+		if (name == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for interpret-field name");
+		else if (pData == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
+		else if (args == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
+		else if (type_str == NULL)
+			ln_dbgprintf(ctx, "no type provided for interpretation of field: %s", name);
+		else if (bad_interpret != 0)
+			ln_dbgprintf(ctx, "interpretation to unknown type '%s' requested for field: %s",
+				type_str, name);
+		else if (field_type == NULL)
+			ln_dbgprintf(ctx, "field-type to actually match the content not provided for "
+				"field: %s", name);
+		else if (pData->ctx == NULL)
+			ln_dbgprintf(ctx, "couldn't instantiate the normalizer context for matching "
+				"field: %s", name);
 
 		interpret_parser_data_destructor((void**) &pData);
 	}
@@ -1594,10 +1635,10 @@ FAILParser
 } ENDFailParser
 
 static struct suffixed_parser_data_s* _suffixed_parser_data_constructor(ln_fieldList_t *node,
-																 ln_ctx ctx,
-																 es_str_t* raw_args,
-																 const char* value_field,
-																 const char* suffix_field) {
+	ln_ctx ctx,
+	es_str_t* raw_args,
+	const char* value_field,
+	const char* suffix_field) {
 	int r = LN_BADCONFIG;
 	pcons_args_t* args = NULL;
 	char* name = NULL;
@@ -1657,26 +1698,37 @@ static struct suffixed_parser_data_s* _suffixed_parser_data_constructor(ln_field
 	r = 0;
 done:
 	if (r != 0) {
-		if (name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory suffixed-field name");
-		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
+		if (name == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory suffixed-field name");
+		else if (pData == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
 		else if (pData->value_field_name == NULL)
 			ln_dbgprintf(ctx, "couldn't allocate memory for value-field's name for field: %s", name);
 		else if (pData->suffix_field_name == NULL)
 			ln_dbgprintf(ctx, "couldn't allocate memory for suffix-field's name for field: %s", name);
-		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
-		else if (escaped_tokenizer == NULL) ln_dbgprintf(ctx, "suffix token-string missing for field: '%s'", name);
+		else if (args == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
+		else if (escaped_tokenizer == NULL)
+			ln_dbgprintf(ctx, "suffix token-string missing for field: '%s'", name);
 		else if (tokenizer == NULL)
-			ln_dbgprintf(ctx, "couldn't allocate memory for unescaping token-string for field: '%s'", name);
-		else if (uncopied_suffixes_str == NULL)  ln_dbgprintf(ctx, "suffix-list missing for field: '%s'", name);
-		else if (suffixes_str == NULL)  ln_dbgprintf(ctx, "couldn't allocate memory for suffix-list for field: '%s'", name);
-		else if (pData->nsuffix == 0)  ln_dbgprintf(ctx, "could't read suffix-value(s) for field: '%s'", name);
+			ln_dbgprintf(ctx, "couldn't allocate memory for unescaping token-string for field: '%s'",
+				name);
+		else if (uncopied_suffixes_str == NULL)
+			ln_dbgprintf(ctx, "suffix-list missing for field: '%s'", name);
+		else if (suffixes_str == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for suffix-list for field: '%s'", name);
+		else if (pData->nsuffix == 0)
+			ln_dbgprintf(ctx, "couldn't read suffix-value(s) for field: '%s'", name);
 		else if (pData->suffix_offsets == NULL)
-			ln_dbgprintf(ctx, "couldn't allocate memory for suffix-list element references for field: '%s'", name);
+			ln_dbgprintf(ctx, "couldn't allocate memory for suffix-list element references for field: "
+				"'%s'", name);
 		else if (pData->suffix_lengths == NULL)
-			ln_dbgprintf(ctx, "couldn't allocate memory for suffix-list element lengths for field: '%s'", name);
+			ln_dbgprintf(ctx, "couldn't allocate memory for suffix-list element lengths for field: '%s'",
+				name);
 		else if (pData->suffixes_str == NULL)
 			ln_dbgprintf(ctx, "couldn't allocate memory for suffix-list for field: '%s'", name);
-		else if (field_type == NULL)  ln_dbgprintf(ctx, "field-type declaration missing for field: '%s'", name);
+		else if (field_type == NULL)
+			ln_dbgprintf(ctx, "field-type declaration missing for field: '%s'", name);
 		else if (pData->ctx == NULL)
 			ln_dbgprintf(ctx, "couldn't allocate memory for normalizer-context for field: '%s'", name);
 		suffixed_parser_data_destructor((void**)&pData);
@@ -1707,17 +1759,24 @@ void* named_suffixed_parser_data_constructor(ln_fieldList_t *node, ln_ctx ctx) {
 	CHKN(remaining_args = pcons_arg(args, 2, NULL));
 	CHKN(unnamed_suffix_args = es_newStrFromCStr(remaining_args, strlen(remaining_args)));
 	
-	CHKN(pData = _suffixed_parser_data_constructor(node, ctx, unnamed_suffix_args, value_field_name, suffix_field_name));
+	CHKN(pData = _suffixed_parser_data_constructor(node, ctx, unnamed_suffix_args, value_field_name,
+		suffix_field_name));
 	r = 0;
 done:
 	if (r != 0) {
-		if (name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory named_suffixed-field name");
-		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
-		else if (value_field_name == NULL) ln_dbgprintf(ctx, "key-name for value not provided for field: %s", name);
-		else if (suffix_field_name == NULL) ln_dbgprintf(ctx, "key-name for suffix not provided for field: %s", name);
+		if (name == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory named_suffixed-field name");
+		else if (args == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
+		else if (value_field_name == NULL)
+			ln_dbgprintf(ctx, "key-name for value not provided for field: %s", name);
+		else if (suffix_field_name == NULL)
+			ln_dbgprintf(ctx, "key-name for suffix not provided for field: %s", name);
 		else if (unnamed_suffix_args == NULL)
-			ln_dbgprintf(ctx, "couldn't allocate memory for unnamed-suffix-field args for field: %s", name);
-		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't create parser-data for field: %s", name);
+			ln_dbgprintf(ctx, "couldn't allocate memory for unnamed-suffix-field args for field: %s",
+				name);
+		else if (pData == NULL)
+			ln_dbgprintf(ctx, "couldn't create parser-data for field: %s", name);
 		suffixed_parser_data_destructor((void**)&pData);
 	}
 	if (unnamed_suffix_args != NULL) free(unnamed_suffix_args);
@@ -2021,7 +2080,8 @@ PARSER(CiscoInterfaceSpec)
 	json_object *json;
 	if(bHaveInterface) {
 		CHKN(json = json_object_new_string_len(c+idxInterface, lenInterface));
-		json_object_object_add_ex(*value, "interface", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
+		json_object_object_add_ex(*value, "interface", json,
+			JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 	}
 	CHKN(json = json_object_new_string_len(c+idxIP, lenIP));
 	json_object_object_add_ex(*value, "ip", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
@@ -2029,13 +2089,16 @@ PARSER(CiscoInterfaceSpec)
 	json_object_object_add_ex(*value, "port", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 	if(bHaveIP2) {
 		CHKN(json = json_object_new_string_len(c+idxIP2, lenIP2));
-		json_object_object_add_ex(*value, "ip2", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
+		json_object_object_add_ex(*value, "ip2", json,
+			JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 		CHKN(json = json_object_new_string_len(c+idxPort2, lenPort2));
-		json_object_object_add_ex(*value, "port2", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
+		json_object_object_add_ex(*value, "port2", json,
+			JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 	}
 	if(bHaveUser) {
 		CHKN(json = json_object_new_string_len(c+idxUser, lenUser));
-		json_object_object_add_ex(*value, "user", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
+		json_object_object_add_ex(*value, "user", json,
+			JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 	}
 
 success: /* success, persist */
@@ -2377,6 +2440,7 @@ parseIPTablesNameValue(const char *const __restrict__ str,
 {
 	int r = LN_WRONGPARSER;
 	size_t i = *offs;
+	char *name = NULL;
 
 	const size_t iName = i;
 	while(i < strLen && isValidIPTablesNameChar(str[i]))
@@ -2404,7 +2468,6 @@ parseIPTablesNameValue(const char *const __restrict__ str,
 	if(valroot == NULL)
 		goto done;
 
-	char *name;
 	CHKN(name = malloc(lenName+1));
 	memcpy(name, str+iName, lenName);
 	name[lenName] = '\0';
@@ -2415,8 +2478,8 @@ parseIPTablesNameValue(const char *const __restrict__ str,
 		CHKN(json = json_object_new_string_len(str+iVal, lenVal));
 	}
 	json_object_object_add(valroot, name, json);
-	free(name);
 done:
+	free(name);
 	return r;
 }
 
@@ -2562,6 +2625,7 @@ parseNameValue(const char *const __restrict__ str,
 {
 	int r = LN_WRONGPARSER;
 	size_t i = *offs;
+	char *name = NULL;
 
 	const size_t iName = i;
 	while(i < strLen && isValidNameChar(str[i]))
@@ -2584,15 +2648,14 @@ parseNameValue(const char *const __restrict__ str,
 	if(valroot == NULL)
 		goto done;
 
-	char *name;
 	CHKN(name = malloc(lenName+1));
 	memcpy(name, str+iName, lenName);
 	name[lenName] = '\0';
 	json_object *json;
 	CHKN(json = json_object_new_string_len(str+iVal, lenVal));
 	json_object_object_add(valroot, name, json);
-	free(name);
 done:
+	free(name);
 	return r;
 }
 
@@ -2815,7 +2878,7 @@ done:
  * of end of name.
  * Note: ArcSight violates the CEF spec ifself: they generate
  * leading underscores in their extension names, which are
- * definetly not alphanumeric. We still accept them...
+ * definitely not alphanumeric. We still accept them...
  * They also seem to use dots.
  */
 static int
@@ -2977,7 +3040,7 @@ PARSER(CEF)
 	char *name = NULL;
 	char *severity = NULL;
 
-	/* minumum header: "CEF:0|x|x|x|x|x|x|" -->  17 chars */
+	/* minimum header: "CEF:0|x|x|x|x|x|x|" -->  17 chars */
 	if(strLen < i + 17 ||
 	   str[i]   != 'C' ||
 	   str[i+1] != 'E' ||
@@ -3002,7 +3065,7 @@ PARSER(CEF)
 	 * This time, we do NOT pre-process the extension, but rather
 	 * persist them directly to JSON. This is contrary to other
 	 * parsers, but as the CEF header is pretty unique, this time
-	 * it is exteremely unlike we will get a no-match during
+	 * it is extremely unlikely we will get a no-match during
 	 * extension processing. Even if so, nothing bad happens, as
 	 * the extracted data is discarded. But the regular case saves
 	 * us processing time and complexity. The only time when we
