@@ -1,7 +1,8 @@
+#!/bin/bash
 # added 2015-03-01 by Rainer Gerhards
 # This file is part of the liblognorm project, released under ASL 2.0
-
 . $srcdir/exec.sh
+no_solaris10
 
 test_def $0 "hexnumber field"
 add_rule 'rule=:here is a number %num:hexnumber% in hex form'
